@@ -198,7 +198,7 @@ class PsmPy:
 
             # return predicted_data
 
-    def knn_matched(self, matcher, treatment, replacement=False, caliper=None):
+    def knn_matched(self, matcher, replacement=False, caliper=None):
         """
         knn_matched -- Match data using k-nn algorithm
         Parameters
